Package: dipsaus
Type: Package
Title: A Dipping Sauce for Data Analysis and Visualizations
Version: 0.3.5
Authors@R: c(
    person("Zhengjia", "Wang", email = "dipterix.wang@gmail.com", role = c("aut", "cre")),
    person("John", "Magnotti", email = "John.Magnotti@pennmedicine.upenn.edu", role = c("ctb"),
    comment = "Contributed to `rutabaga.R`"),
    person("Xiang", "Zhang", email = "xiang.zhang@pennmedicine.upenn.edu", role = c("ctb"),
    comment = "Contributed to `rutabaga.R`")
    )
Description: Works as an "add-on" to packages like 'shiny', 'future', as well as 
    'rlang', and provides utility functions. Just like dipping sauce adding 
    flavors to potato chips or pita bread, 'dipsaus' for data analysis and 
    visualizations adds handy functions and enhancements to popular packages. 
    The goal is to provide simple solutions that are frequently asked for 
    online, such as how to synchronize 'shiny' inputs without freezing the app,
    or how to get memory size on 'Linux' or 'MacOS' system. The enhancements 
    roughly fall into these four categories: 1. 'shiny' input widgets; 2. 
    high-performance computing using the 'future' package; 3. 
    modify R calls and convert among numbers, strings, and other objects. 4. 
    utility functions to get system information such like CPU chip-set, memory 
    limit, etc.
URL: https://github.com/dipterix/dipsaus, https://dipterix.org/dipsaus/
BugReports: https://github.com/dipterix/dipsaus/issues
License: GPL-3
Encoding: UTF-8
Language: en-US
Depends: R (>= 4.1.0)
Imports: utils, stats, graphics, grDevices, parallel, Rcpp, R6, shiny,
        cli, stringr, jsonlite (>= 1.6), future, future.apply,
        parallelly, progressr, fastmap (>= 1.1.0), base64enc, digest,
        rlang (>= 0.4.0), rstudioapi (>= 0.11)
Suggests: knitr, promises, later, rmarkdown, testthat, microbenchmark,
        yaml, future.callr
LinkingTo: Rcpp
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-05-22 17:55:13 UTC; dipterix
Author: Zhengjia Wang [aut, cre],
  John Magnotti [ctb] (Contributed to `rutabaga.R`),
  Xiang Zhang [ctb] (Contributed to `rutabaga.R`)
Maintainer: Zhengjia Wang <dipterix.wang@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-23 05:10:48 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-05-25 02:09:00 UTC; unix
Archs: dipsaus.so.dSYM
