# Generated by roxygen2: do not edit by hand

S3method("$",fastmap2)
S3method("$<-",fastmap2)
S3method("$<-",fastqueue2)
S3method("[",fastmap2)
S3method("[",fastqueue2)
S3method("[<-",fastmap2)
S3method("[<-",fastqueue2)
S3method("[[",fastmap2)
S3method("[[",fastqueue2)
S3method("[[<-",fastmap2)
S3method("[[<-",fastqueue2)
S3method(as.character,dipsaus_bytes)
S3method(as.character,sexp_type2)
S3method(as.list,fastmap2)
S3method(as.list,fastqueue2)
S3method(length,fastmap2)
S3method(length,fastqueue2)
S3method(names,fastmap2)
S3method(print,dipsaus_bytes)
S3method(print,dipsaus_compoundInput_data)
S3method(print,dipsaus_decorated)
S3method(print,dipsaus_rs_exec_res)
S3method(print,f_pipe)
S3method(print,fastmap2)
S3method(print,fastqueue2)
S3method(print,sexp_type2)
S3method(shared_finalizer,R6)
S3method(shared_finalizer,default)
S3method(shared_finalizer,fastmap)
S3method(shared_finalizer,fastmap2)
S3method(ste_mean,default)
export("%+-%")
export("%<-?%")
export("%=>%")
export("%?<-%")
export("%D%")
export("%OF%")
export(AbstractQueue)
export(PersistContainer)
export(abort)
export(actionButtonStyled)
export(add_to_session)
export(ansi_strip)
export(as_pipe)
export(ask_or_default)
export(ask_yesno)
export(async)
export(async_expr)
export(async_flapply)
export(async_works)
export(base64_to_image)
export(base64_to_string)
export(base64_urldecode)
export(base64_urlencode)
export(baseline_array)
export(capture_expr)
export(cat2)
export(check_installed_packages)
export(clear_env)
export(close_alert2)
export(cnd_entrace)
export(col2hexStr)
export(collapse)
export(combine_html_class)
export(compoundInput2)
export(decorate_function)
export(deparse_svec)
export(detectCores)
export(dev_create)
export(digest)
export(digest2)
export(dipsaus_lock)
export(dipsaus_resetlocks)
export(dipsaus_unlock)
export(do_aggregate)
export(do_nothing)
export(drop_nulls)
export(entrace)
export(error_cnd)
export(eval_dirty)
export(fancyDirectoryInput)
export(fancyFileInput)
export(fastcov2)
export(fastmap2)
export(fastquantile)
export(fastqueue2)
export(flex_div)
export(forelse)
export(fromJSON)
export(getInputBinding)
export(get_cpu)
export(get_credential)
export(get_dev_attr)
export(get_dipsaus_upload_dir)
export(get_dots)
export(get_ip)
export(get_os)
export(get_ram)
export(handler_dipsaus_progress)
export(html_asis)
export(iapply)
export(is_from_namespace)
export(lapply_async2)
export(lapply_callr)
export(list_to_fastmap2)
export(list_to_fastqueue2)
export(make_forked_clusters)
export(mask_function2)
export(match_calls)
export(mean_se)
export(mem_limit2)
export(missing_dots)
export(new_function2)
export(no_op)
export(observeDirectoryProgress)
export(package_installed)
export(parse_svec)
export(print_directory_tree)
export(progress2)
export(rds_map)
export(read_json)
export(registerInputBinding)
export(remove_html_class)
export(restart_session)
export(rs_active_project)
export(rs_add_insertion_shortcut)
export(rs_add_shortcut)
export(rs_avail)
export(rs_edit_file)
export(rs_exec)
export(rs_focus_console)
export(rs_quick_debug)
export(rs_remove_shortcut)
export(rs_save_all)
export(rs_select_path)
export(rs_set_repos)
export(rs_show_shortcut)
export(rs_viewer)
export(screenshot)
export(serializeJSON)
export(session_map)
export(session_uuid)
export(set_shiny_input)
export(sexp_type2)
export(shared_finalizer)
export(shift_array)
export(shiny_alert2)
export(shiny_is_running)
export(ste_mean)
export(stream_download)
export(sumsquared)
export(sync_shiny_inputs)
export(test_farg)
export(text_map)
export(time_delta)
export(toJSON)
export(to_datauri)
export(to_ram_size)
export(trace_back)
export(tree)
export(unserializeJSON)
export(updateActionButtonStyled)
export(updateCompoundInput2)
export(use_shiny_dipsaus)
export(write_json)
importFrom(R6,R6Class)
importFrom(Rcpp,sourceCpp)
importFrom(cli,ansi_strip)
importFrom(cli,tree)
importFrom(digest,digest)
importFrom(fastmap,fastmap)
importFrom(graphics,par)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,read_json)
importFrom(jsonlite,serializeJSON)
importFrom(jsonlite,toJSON)
importFrom(jsonlite,unserializeJSON)
importFrom(jsonlite,write_json)
importFrom(parallel,clusterEvalQ)
importFrom(parallel,detectCores)
importFrom(parallel,stopCluster)
importFrom(parallelly,availableCores)
importFrom(rlang,abort)
importFrom(rlang,cnd_entrace)
importFrom(rlang,entrace)
importFrom(rlang,error_cnd)
importFrom(rlang,trace_back)
importFrom(shiny,actionButton)
importFrom(utils,flush.console)
useDynLib(dipsaus, .registration = TRUE)
